// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef AKONADICALENDAR_VERSION_H
#define AKONADICALENDAR_VERSION_H

#define AKONADICALENDAR_VERSION_STRING "6.7.3"
#define AKONADICALENDAR_VERSION_MAJOR 6
#define AKONADICALENDAR_VERSION_MINOR 7
#define AKONADICALENDAR_VERSION_PATCH 3
#define AKONADICALENDAR_VERSION ((6<<16)|(7<<8)|(3))

#endif
